@@ -8,11 +8,13 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include <config-libkleo.h>
+
 #include "editdirectoryservicedialog.h"
 
-#include "kleo/keyserverconfig.h"
-#include "utils/algorithm.h"
-#include "utils/gnupg.h"
+#include <libkleo/algorithm.h>
+#include <libkleo/gnupg.h>
+#include <libkleo/keyserverconfig.h>
 
 #include <KCollapsibleGroupBox>
 #include <KConfigGroup>
@@ -27,7 +29,6 @@
 #include <QDialogButtonBox>
 #include <QGridLayout>
 #include <QGroupBox>
-#include <QHBoxLayout>
 #include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
@@ -75,7 +76,7 @@ class EditDirectoryServiceDialog::Private
             , additionalFlagsEdit{new QLineEdit{parent}}
             , buttonBox{new QDialogButtonBox{parent}}
         {
-#define SET_OBJECT_NAME( x ) x->setObjectName(QStringLiteral( #x ));
+#define SET_OBJECT_NAME(x) x->setObjectName(QStringLiteral(#x));
             SET_OBJECT_NAME(hostEdit)
             SET_OBJECT_NAME(portSpinBox)
             SET_OBJECT_NAME(useDefaultPortCheckBox)
@@ -96,8 +97,7 @@ class EditDirectoryServiceDialog::Private
                 layout->setColumnStretch(2, 1);
                 int row = 0;
                 layout->addWidget(new QLabel{i18n("Host:")}, row, 0);
-                hostEdit->setToolTip(i18nc("@info:tooltip",
-                                           "Enter the name or IP address of the server hosting the directory service."));
+                hostEdit->setToolTip(i18nc("@info:tooltip", "Enter the name or IP address of the server hosting the directory service."));
                 hostEdit->setClearButtonEnabled(true);
                 layout->addWidget(hostEdit, row, 1, 1, -1);
                 ++row;
@@ -118,8 +118,7 @@ class EditDirectoryServiceDialog::Private
                 auto layout = new QVBoxLayout{authenticationWidget};
                 {
                     auto radioButton = new QRadioButton{i18n("Anonymous")};
-                    radioButton->setToolTip(i18nc("@info:tooltip",
-                                                  "Use an anonymous LDAP server that does not require authentication."));
+                    radioButton->setToolTip(i18nc("@info:tooltip", "Use an anonymous LDAP server that does not require authentication."));
                     radioButton->setChecked(true);
                     authenticationGroup->addButton(radioButton, static_cast<int>(KeyserverAuthentication::Anonymous));
                     layout->addWidget(radioButton);
@@ -129,15 +128,14 @@ class EditDirectoryServiceDialog::Private
                     if (!engineIsVersion(2, 2, 28, GpgME::GpgSMEngine)) {
                         radioButton->setText(i18n("Authenticate via Active Directory (requires GnuPG 2.2.28 or later)"));
                     }
-                    radioButton->setToolTip(i18nc("@info:tooltip",
-                                                  "On Windows, authenticate to the LDAP server using the Active Directory with the current user."));
+                    radioButton->setToolTip(
+                        i18nc("@info:tooltip", "On Windows, authenticate to the LDAP server using the Active Directory with the current user."));
                     authenticationGroup->addButton(radioButton, static_cast<int>(KeyserverAuthentication::ActiveDirectory));
                     layout->addWidget(radioButton);
                 }
                 {
                     auto radioButton = new QRadioButton{i18n("Authenticate with user and password")};
-                    radioButton->setToolTip(i18nc("@info:tooltip",
-                                                  "Authenticate to the LDAP server with your LDAP credentials."));
+                    radioButton->setToolTip(i18nc("@info:tooltip", "Authenticate to the LDAP server with your LDAP credentials."));
                     authenticationGroup->addButton(radioButton, static_cast<int>(KeyserverAuthentication::Password));
                     layout->addWidget(radioButton);
                 }
@@ -148,8 +146,7 @@ class EditDirectoryServiceDialog::Private
                     layout->setColumnStretch(1, 1);
                     int row = 0;
                     layout->addWidget(new QLabel{i18n("User:")}, row, 0);
-                    userEdit->setToolTip(i18nc("@info:tooltip",
-                                               "Enter your LDAP user resp. Bind DN for authenticating to the LDAP server."));
+                    userEdit->setToolTip(i18nc("@info:tooltip", "Enter your LDAP user resp. Bind DN for authenticating to the LDAP server."));
                     userEdit->setClearButtonEnabled(true);
                     layout->addWidget(userEdit, row, 1);
                     ++row;
@@ -280,15 +277,15 @@ class EditDirectoryServiceDialog::Private
 
     QStringList additionalFlags() const
     {
-        return transformInPlace(ui.additionalFlagsEdit->text().split(QLatin1Char{','}, Qt::SkipEmptyParts),
-                                [] (const auto &flag) { return flag.trimmed(); });
+        return transformInPlace(ui.additionalFlagsEdit->text().split(QLatin1Char{','}, Qt::SkipEmptyParts), [](const auto &flag) {
+            return flag.trimmed();
+        });
     }
 
     bool inputIsAcceptable() const
     {
         const bool hostIsSet = !host().isEmpty();
-        const bool requiredCredentialsAreSet = authentication() != KeyserverAuthentication::Password
-            || (!user().isEmpty() && !password().isEmpty());
+        const bool requiredCredentialsAreSet = authentication() != KeyserverAuthentication::Password || (!user().isEmpty() && !password().isEmpty());
         return hostIsSet && requiredCredentialsAreSet;
     }
 
@@ -310,12 +307,24 @@ public:
         : q{q}
         , ui{q}
     {
-        connect(ui.hostEdit, &QLineEdit::textEdited, q, [this] () { updateWidgets(); });
-        connect(ui.useDefaultPortCheckBox, &QCheckBox::toggled, q, [this] () { updateWidgets(); });
-        connect(ui.authenticationGroup, &QButtonGroup::idToggled, q, [this] () { updateWidgets(); });
-        connect(ui.userEdit, &QLineEdit::textEdited, q, [this] () { updateWidgets(); });
-        connect(ui.passwordEdit, &KPasswordLineEdit::passwordChanged, q, [this] () { updateWidgets(); });
-        connect(ui.connectionGroup, &QButtonGroup::idToggled, q, [this] () { updateWidgets(); });
+        connect(ui.hostEdit, &QLineEdit::textEdited, q, [this]() {
+            updateWidgets();
+        });
+        connect(ui.useDefaultPortCheckBox, &QCheckBox::toggled, q, [this]() {
+            updateWidgets();
+        });
+        connect(ui.authenticationGroup, &QButtonGroup::idToggled, q, [this]() {
+            updateWidgets();
+        });
+        connect(ui.userEdit, &QLineEdit::textEdited, q, [this]() {
+            updateWidgets();
+        });
+        connect(ui.passwordEdit, &KPasswordLineEdit::passwordChanged, q, [this]() {
+            updateWidgets();
+        });
+        connect(ui.connectionGroup, &QButtonGroup::idToggled, q, [this]() {
+            updateWidgets();
+        });
 
         connect(ui.buttonBox, &QDialogButtonBox::accepted, q, &EditDirectoryServiceDialog::accept);
         connect(ui.buttonBox, &QDialogButtonBox::rejected, q, &EditDirectoryServiceDialog::reject);
@@ -330,7 +339,7 @@ public:
         saveLayout();
     }
 
-    void setKeyserver(const KeyserverConfig& keyserver)
+    void setKeyserver(const KeyserverConfig &keyserver)
     {
         ui.hostEdit->setText(keyserver.host());
         ui.useDefaultPortCheckBox->setChecked(keyserver.port() == -1);
@@ -364,14 +373,14 @@ public:
 private:
     void saveLayout()
     {
-        KConfigGroup configGroup{KSharedConfig::openStateConfig(), "EditDirectoryServiceDialog"};
+        KConfigGroup configGroup{KSharedConfig::openStateConfig(), QLatin1String("EditDirectoryServiceDialog")};
         configGroup.writeEntry("Size", q->size());
         configGroup.sync();
     }
 
     void restoreLayout()
     {
-        const KConfigGroup configGroup{KSharedConfig::openStateConfig(), "EditDirectoryServiceDialog"};
+        const KConfigGroup configGroup{KSharedConfig::openStateConfig(), QLatin1String("EditDirectoryServiceDialog")};
         const auto size = configGroup.readEntry("Size", QSize{});
         if (size.isValid()) {
             q->resize(size);
@@ -388,7 +397,7 @@ EditDirectoryServiceDialog::EditDirectoryServiceDialog(QWidget *parent, Qt::Wind
 
 EditDirectoryServiceDialog::~EditDirectoryServiceDialog() = default;
 
-void EditDirectoryServiceDialog::setKeyserver(const KeyserverConfig& keyserver)
+void EditDirectoryServiceDialog::setKeyserver(const KeyserverConfig &keyserver)
 {
     d->setKeyserver(keyserver);
 }
@@ -397,3 +406,5 @@ KeyserverConfig EditDirectoryServiceDialog::keyserver() const
 {
     return d->keyserver();
 }
+
+#include "moc_editdirectoryservicedialog.cpp"
