@@ -31,8 +31,8 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
-#include <QGpgME/DefaultKeyGenerationJob>
-#include <QGpgME/Job>
+#include <QGpgME/Protocol>
+#include <QGpgME/QuickJob>
 
 #include <QButtonGroup>
 #include <QCheckBox>
@@ -48,6 +48,7 @@
 #include <QToolTip>
 #include <QVBoxLayout>
 
+#include <gpgme++/context.h>
 #include <gpgme++/key.h>
 #include <gpgme++/keygenerationresult.h>
 
@@ -277,7 +278,7 @@ public:
         QDialogButtonBox *btnBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
         mOkButton = btnBox->button(QDialogButtonBox::Ok);
 #ifndef NDEBUG
-        mOkButton->setObjectName(QStringLiteral("ok button"));
+        mOkButton->setObjectName(QLatin1StringView("ok button"));
 #endif
         QObject::connect(btnBox, &QDialogButtonBox::accepted, q, [this]() {
             accepted();
@@ -307,8 +308,8 @@ public:
             smimeBtn = new QRadioButton(i18n("S/MIME"));
         }
 #ifndef NDEBUG
-        pgpBtn->setObjectName(QStringLiteral("openpgp button"));
-        smimeBtn->setObjectName(QStringLiteral("smime button"));
+        pgpBtn->setObjectName(QLatin1StringView("openpgp button"));
+        smimeBtn->setObjectName(QLatin1StringView("smime button"));
 #endif
         mFormatBtns->addButton(pgpBtn, OpenPGPButtonId);
         mFormatBtns->addButton(smimeBtn, SMIMEButtonId);
@@ -346,7 +347,7 @@ public:
         mComplianceLbl = new QLabel;
         mComplianceLbl->setVisible(false);
 #ifndef NDEBUG
-        mComplianceLbl->setObjectName(QStringLiteral("compliance label"));
+        mComplianceLbl->setObjectName(QLatin1StringView("compliance label"));
 #endif
 
         auto btnLayout = new QHBoxLayout;
@@ -388,8 +389,11 @@ public:
 
     void generateKey(KeySelectionCombo *combo)
     {
+        if (!mRunningJobs.empty()) {
+            return;
+        }
         const auto &addr = combo->property("address").toString();
-        auto job = new QGpgME::DefaultKeyGenerationJob(q);
+        auto job = QGpgME::openpgp()->quickJob();
         auto progress =
             new Kleo::ProgressDialog(job, i18n("Generating key for '%1'...", addr) + QStringLiteral("\n\n") + i18n("This can take several minutes."), q);
         progress->setWindowFlags(progress->windowFlags() & ~Qt::WindowContextHelpButtonHint);
@@ -400,22 +404,30 @@ public:
         progress->setValue(0);
 
         mRunningJobs << job;
-        connect(job, &QGpgME::DefaultKeyGenerationJob::result, q, [this, job, combo](const GpgME::KeyGenerationResult &result) {
-            handleKeyGenResult(result, job, combo);
-        });
-        job->start(addr, QString());
+        if (!connect(job, &QGpgME::QuickJob::result, q, [this, job, combo]() {
+                handleKeyGenResult(QGpgME::Job::context(job)->keyGenerationResult(), job, combo);
+            })) {
+            qCWarning(LIBKLEO_LOG) << "new-style connect failed; connecting to QGpgME::QuickJob::result the old way";
+            connect(job, SIGNAL(result(const GpgME::Error &)), q, SLOT(handleKeyGenResult()));
+        }
+        job->startCreate(addr, nullptr);
         return;
     }
 
     void handleKeyGenResult(const GpgME::KeyGenerationResult &result, QGpgME::Job *job, KeySelectionCombo *combo)
     {
         mLastError = result.error();
-        if (!mLastError || mLastError.isCanceled()) {
-            combo->setDefaultKey(QString::fromLatin1(result.fingerprint()), GpgME::OpenPGP);
+        if (!mLastError) {
             connect(combo, &KeySelectionCombo::keyListingFinished, q, [this, job]() {
                 mRunningJobs.removeAll(job);
             });
-            combo->refreshKeys();
+            // update all combos showing the GenerateKey item
+            for (auto c : std::as_const(mAllCombos)) {
+                if (c->currentData(Qt::UserRole).toInt() == GenerateKey) {
+                    c->setDefaultKey(QString::fromLatin1(result.fingerprint()), GpgME::OpenPGP);
+                    c->refreshKeys();
+                }
+            }
         } else {
             mRunningJobs.removeAll(job);
         }
@@ -423,7 +435,7 @@ public:
 
     void checkAccepted()
     {
-        if (mLastError || mLastError.isCanceled()) {
+        if (mLastError) {
             KMessageBox::error(q, Formatting::errorAsString(mLastError), i18n("Operation Failed"));
             mRunningJobs.clear();
             return;
@@ -512,7 +524,7 @@ public:
     auto createProtocolLabel(GpgME::Protocol protocol)
     {
         auto label = new QLabel(Formatting::displayName(protocol));
-        label->setObjectName(QStringLiteral("protocol label"));
+        label->setObjectName(QLatin1StringView("protocol label"));
         return label;
     }
 
@@ -524,7 +536,7 @@ public:
         auto combo = new KeySelectionCombo{true, KeyUsage::Sign};
         auto comboWidget = new ComboWidget(combo);
 #ifndef NDEBUG
-        combo->setObjectName(QStringLiteral("signing key"));
+        combo->setObjectName(QLatin1StringView("signing key"));
 #endif
         if (protocol == GpgME::OpenPGP) {
             combo->setKeyFilter(s_pgpSignFilter);
@@ -617,7 +629,7 @@ public:
         auto combo = new KeySelectionCombo{false, KeyUsage::Encrypt};
         auto comboWidget = new ComboWidget(combo);
 #ifndef NDEBUG
-        combo->setObjectName(QStringLiteral("encryption key"));
+        combo->setObjectName(QLatin1StringView("encryption key"));
 #endif
         if (fixedProtocol == GpgME::OpenPGP) {
             combo->setKeyFilter(s_pgpEncryptFilter);
@@ -761,7 +773,7 @@ public:
         {
             auto group = new QGroupBox(i18nc("Encrypt to self (email address):", "Encrypt to self (%1):", mSender));
 #ifndef NDEBUG
-            group->setObjectName(QStringLiteral("encrypt-to-self box"));
+            group->setObjectName(QLatin1StringView("encrypt-to-self box"));
 #endif
             group->setAlignment(Qt::AlignLeft);
             auto encGrid = new QGridLayout(group);
@@ -778,7 +790,7 @@ public:
         if (hasOtherRecipients) {
             auto group = new QGroupBox(i18n("Encrypt to others:"));
 #ifndef NDEBUG
-            group->setObjectName(QStringLiteral("encrypt-to-others box"));
+            group->setObjectName(QLatin1StringView("encrypt-to-others box"));
 #endif
             group->setAlignment(Qt::AlignLeft);
             auto encGrid = new QGridLayout{group};
@@ -906,6 +918,17 @@ KeyResolver::Solution NewKeyApprovalDialog::result()
     return d->mAcceptedResult;
 }
 
+void NewKeyApprovalDialog::handleKeyGenResult()
+{
+    if (d->mRunningJobs.empty()) {
+        qCWarning(LIBKLEO_LOG) << __func__ << "No running job";
+    }
+    const auto job = d->mRunningJobs.front();
+    const auto result = QGpgME::Job::context(job)->keyGenerationResult();
+    const auto combo = d->findVisibleKeySelectionComboWithGenerateKey();
+    d->handleKeyGenResult(result, job, combo);
+}
+
 #include "newkeyapprovaldialog.moc"
 
 #include "moc_newkeyapprovaldialog.cpp"
